import config


class Index:

    def GET(self):
        result = config.model.get_all_table_name().list()
        for row in result:
            row.primary_key = config.make_secure_val(str(row.primary_key))
        return config.render.index(result)


import config


class Edit:

    def GET(self, primary_key, message=None):
        primary_key = config.check_secure_val(str(primary_key))
        result = config.model.get_table_name(int(primary_key))
        result.primary_key = config.make_secure_val(str(result.primary_key))
        return config.render.edit(result, message)

    def POST(self, primary_key, message=None):
        form = config.web.input()
        form['primary_key'] = config.check_secure_val(str(form['primary_key']))
        res = config.model.edit_table_name(
            fields
        )
        if res == 0:
            primary_key = config.check_secure_val(str(primary_key))
            result = config.model.get_table_name(int(primary_key))
            result.primary_key = config.make_secure_val(str(result.primary_key))
            message = "Error al editar el registro"
            return config.render.edit(result, message)
        else:
            raise config.web.seeother('/table_name')


import web
import hmac
import application.models.model_table_name

render = web.template.render('application/views/table_name/', base='master')
model = application.models.model_table_name

secret = "kuorra"


def hash_str(s):
    return hmac.new(secret, s).hexdigest()


def make_secure_val(s):
    return "%s!%s" % (s, hash_str(s))


def check_secure_val(h):
    val = h.split('!')[0]
    if h == make_secure_val(val):
        return val


import config


class View:

    def GET(self, primary_key):
        primary_key = config.check_secure_val(str(primary_key))
        result = config.model.get_table_name(primary_key)
        return config.render.view(result)